@@ -12,8 +12,8 @@ import (
 	"github.com/openshift/elasticsearch-operator/pkg/constants"
 	"github.com/openshift/elasticsearch-operator/pkg/elasticsearch"
 	"github.com/openshift/elasticsearch-operator/pkg/k8shandler/migrations"
+	"github.com/openshift/elasticsearch-operator/pkg/log"
 	"github.com/openshift/elasticsearch-operator/pkg/utils"
-	"github.com/sirupsen/logrus"
 	apps "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -21,7 +21,6 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/client-go/util/retry"
-	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
 	"sigs.k8s.io/controller-runtime/pkg/client"
 )
@@ -39,39 +38,7 @@ var (
 	}
 )
 
-func Reconcile(request reconcile.Request, k8sClient client.Client, esClient elasticsearch.Client) error {
-	kibanaInstance := &kibana.Kibana{}
-	key := types.NamespacedName{
-		Name:      request.Name,
-		Namespace: request.Namespace,
-	}
-
-	err := k8sClient.Get(context.TODO(), key, kibanaInstance)
-	if err != nil {
-		if errors.IsNotFound(err) {
-			return nil
-		}
-
-		return err
-	}
-
-	if kibanaInstance.Spec.ManagementState == kibana.ManagementStateUnmanaged {
-		return nil
-	}
-
-	proxyCfg, err := getProxyConfig(k8sClient)
-	if err != nil {
-		return err
-	}
-
-	if err := reconcileKibana(kibanaInstance, k8sClient, esClient, proxyCfg); err != nil {
-		return err
-	}
-
-	return nil
-}
-
-func reconcileKibana(requestCluster *kibana.Kibana, requestClient client.Client, esClient elasticsearch.Client, proxyConfig *configv1.Proxy) error {
+func Reconcile(requestCluster *kibana.Kibana, requestClient client.Client, esClient elasticsearch.Client, proxyConfig *configv1.Proxy) error {
 	clusterKibanaRequest := KibanaRequest{
 		client:   requestClient,
 		cluster:  requestCluster,
@@ -117,7 +84,8 @@ func reconcileKibana(requestCluster *kibana.Kibana, requestClient client.Client,
 		return err
 	}
 
-	if err := clusterKibanaRequest.createOrUpdateKibanaDeployment(proxyConfig); err != nil {
+	clusterName := esClient.ClusterName()
+	if err := clusterKibanaRequest.createOrUpdateKibanaDeployment(proxyConfig, clusterName); err != nil {
 		return err
 	}
 
@@ -125,42 +93,15 @@ func reconcileKibana(requestCluster *kibana.Kibana, requestClient client.Client,
 		return err
 	}
 
-	kibanaStatus, err := clusterKibanaRequest.getKibanaStatus()
-	cluster := clusterKibanaRequest.cluster
-
-	if err != nil {
-		return fmt.Errorf("Failed to get Kibana status for %q: %v", cluster.Name, err)
-	}
-
-	printUpdateMessage := true
-	retryErr := retry.RetryOnConflict(retry.DefaultRetry,
-		func() error {
-			if !compareKibanaStatus(kibanaStatus,
-				cluster.Status) {
-				if printUpdateMessage {
-					logrus.Infof("Updating status of Kibana")
-					printUpdateMessage = false
-				}
-				cluster.Status = kibanaStatus
-				return clusterKibanaRequest.UpdateStatus(cluster)
-			}
-			return nil
-		})
-	if retryErr != nil {
-		return fmt.Errorf("Failed to update Kibana status for %q: %v", cluster.Name, retryErr)
-	}
-	logrus.Infof("Kibana status successfully updated")
-
-	return nil
+	return clusterKibanaRequest.UpdateStatus()
 }
 
-func getProxyConfig(r client.Client) (*configv1.Proxy, error) {
+func GetProxyConfig(r client.Client) (*configv1.Proxy, error) {
 	proxyNamespacedName := types.NamespacedName{Name: constants.ProxyName}
 	proxyConfig := &configv1.Proxy{}
 	if err := r.Get(context.TODO(), proxyNamespacedName, proxyConfig); err != nil {
 		if !apierrors.IsNotFound(err) {
-			return nil, fmt.Errorf("Encountered unexpected error getting %v. Error: %s\r\n", proxyNamespacedName,
-				err.Error())
+			return nil, fmt.Errorf("Encountered unexpected error getting %v. Error: %w", proxyNamespacedName, err)
 		}
 	}
 	return proxyConfig, nil
@@ -229,7 +170,6 @@ func (clusterRequest *KibanaRequest) deleteKibana5Deployment() error {
 	containers := kibana5.Spec.Template.Spec.Containers
 	for _, c := range containers {
 		if c.Image == getImage() {
-			logrus.Debugf("skipping deleting kibana 5 image because kibana 6 installed")
 			return nil
 		}
 	}
@@ -243,7 +183,7 @@ func (clusterRequest *KibanaRequest) deleteKibana5Deployment() error {
 	return nil
 }
 
-func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig *configv1.Proxy) (err error) {
+func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig *configv1.Proxy, clusterName string) (err error) {
 	kibanaTrustBundle := &v1.ConfigMap{}
 
 	// Create cluster proxy trusted CA bundle.
@@ -256,7 +196,7 @@ func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig
 
 	kibanaPodSpec := newKibanaPodSpec(
 		clusterRequest,
-		fmt.Sprintf("elasticsearch.%s.svc.cluster.local", clusterRequest.cluster.Namespace),
+		fmt.Sprintf("%s.%s.svc.cluster.local", clusterName, clusterRequest.cluster.Namespace),
 		proxyConfig,
 		kibanaTrustBundle,
 	)
@@ -294,7 +234,6 @@ func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig
 				if errors.IsNotFound(err) {
 					// the object doesn't exist -- it was likely culled
 					// recreate it on the next time through if necessary
-					logrus.Debugf("Returning nil. The deployment %q was not found even though create previously failed.  Was it culled?", kibanaDeployment.Name)
 					return nil
 				}
 				return fmt.Errorf("failed to get Kibana deployment: %v", err)
@@ -305,6 +244,9 @@ func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig
 			currentTrustedCAHash := current.Spec.Template.ObjectMeta.Annotations[constants.TrustedCABundleHashName]
 			desiredTrustedCAHash := kibanaDeployment.Spec.Template.ObjectMeta.Annotations[constants.TrustedCABundleHashName]
 			if currentTrustedCAHash != desiredTrustedCAHash {
+				if current.Spec.Template.ObjectMeta.Annotations == nil {
+					current.Spec.Template.ObjectMeta.Annotations = map[string]string{}
+				}
 				current.Spec.Template.ObjectMeta.Annotations[constants.TrustedCABundleHashName] = desiredTrustedCAHash
 				different = true
 			}
@@ -315,6 +257,9 @@ func (clusterRequest *KibanaRequest) createOrUpdateKibanaDeployment(proxyConfig
 				desiredHash := kibanaDeployment.Spec.Template.ObjectMeta.Annotations[hashKey]
 
 				if currentHash != desiredHash {
+					if current.Spec.Template.ObjectMeta.Annotations == nil {
+						current.Spec.Template.ObjectMeta.Annotations = map[string]string{}
+					}
 					current.Spec.Template.ObjectMeta.Annotations[hashKey] = desiredHash
 					different = true
 				}
@@ -387,31 +332,27 @@ func isDeploymentDifferent(current *apps.Deployment, desired *apps.Deployment) (
 
 	// is this needed?
 	if !utils.AreMapsSame(current.Spec.Template.Spec.NodeSelector, desired.Spec.Template.Spec.NodeSelector) {
-		logrus.Debugf("Visualization nodeSelector change found, updating '%s'", current.Name)
 		current.Spec.Template.Spec.NodeSelector = desired.Spec.Template.Spec.NodeSelector
 		different = true
 	}
 
 	// is this needed?
 	if !utils.AreTolerationsSame(current.Spec.Template.Spec.Tolerations, desired.Spec.Template.Spec.Tolerations) {
-		logrus.Debugf("Visualization tolerations change found, updating '%s'", current.Name)
 		current.Spec.Template.Spec.Tolerations = desired.Spec.Template.Spec.Tolerations
 		different = true
 	}
 
 	if isDeploymentImageDifference(current, desired) {
-		logrus.Debugf("Visualization image change found, updating %q", current.Name)
 		current = updateCurrentDeploymentImages(current, desired)
 		different = true
 	}
 
 	if utils.AreResourcesDifferent(current, desired) {
-		logrus.Debugf("Visualization resource(s) change found, updating %q", current.Name)
 		different = true
 	}
 
 	if *current.Spec.Replicas != *desired.Spec.Replicas {
-		logrus.Infof("Kibana replicas changed. Previous: %d, Current: %d", *current.Spec.Replicas, *desired.Spec.Replicas)
+		log.Info("Kibana replicas changed", "previous", *current.Spec.Replicas, "current", *desired.Spec.Replicas, "deployment", current.Name)
 		*current.Spec.Replicas = *desired.Spec.Replicas
 		different = true
 	}
